@@ -35,7 +35,7 @@ from metview import plotting
 from metview.metviewpy.ipython import is_ipython_active, import_widgets
 from metview.metviewpy import utils
 
-__version__ = "1.13.1"
+__version__ = "1.14.0"
 
 
 # logging.basicConfig(level=logging.DEBUG, format="%(levelname)s - %(message)s")
@@ -427,18 +427,18 @@ def push_vector(npa):
     dtype = npa.dtype
     if dtype == np.float64:  #  can directly pass the data buffer
         cffi_buffer = ffi.cast("double*", npa.ctypes.data)
-        lib.p_push_vector_from_double_array(cffi_buffer, len(npa), np.nan)
+        lib.p_push_vector_from_double_array(cffi_buffer, npa.size, np.nan)
     elif dtype == np.float32:  #  can directly pass the data buffer
         cffi_buffer = ffi.cast("float*", npa.ctypes.data)
-        lib.p_push_vector_from_float32_array(cffi_buffer, len(npa), np.nan)
+        lib.p_push_vector_from_float32_array(cffi_buffer, npa.size, np.nan)
     elif dtype == bool:  # convert first to float32
         f32_array = npa.astype(np.float32)
         cffi_buffer = ffi.cast("float*", f32_array.ctypes.data)
-        lib.p_push_vector_from_float32_array(cffi_buffer, len(f32_array), np.nan)
+        lib.p_push_vector_from_float32_array(cffi_buffer, f32_array.size, np.nan)
     elif dtype == int:  # convert first to float64
         f64_array = npa.astype(np.float64)
         cffi_buffer = ffi.cast("double*", f64_array.ctypes.data)
-        lib.p_push_vector_from_double_array(cffi_buffer, len(f64_array), np.nan)
+        lib.p_push_vector_from_double_array(cffi_buffer, f64_array.size, np.nan)
     else:
         raise TypeError(
             "Only float32 and float64 numPy arrays can be passed to Metview, not ",
@@ -774,6 +774,9 @@ class Fieldset(FileBackedValueWithOperators, ContainerValue):
             dim, preserve_dims, met_sum, "sum", missing=missing
         )
 
+    def stdev(self, dim=None, preserve_dims=None, missing=False):
+        return self.apply_function_over_dim(dim, preserve_dims, met_stdev, "stdev")
+
     @property
     def ds_param_info(self):
         if self._ds_param_info is None:
@@ -1112,6 +1115,7 @@ def list_from_metview(val):
 
 
 def datestring_from_metview(val):
+
     mdate = string_from_ffi(lib.p_value_as_datestring(val))
     dt = datetime.datetime.strptime(mdate, "%Y-%m-%dT%H:%M:%S")
     lib.p_destroy_value(val)
@@ -1323,6 +1327,7 @@ def bind_functions(namespace, module_name=None):
     namespace["plot_maps"] = plotting.plot_maps
     namespace["plot_diff_maps"] = plotting.plot_diff_maps
     namespace["plot_xs"] = plotting.plot_xs
+    namespace["plot_xs_avg"] = plotting.plot_xs_avg
     namespace["plot_stamp"] = plotting.plot_stamp
     namespace["plot_rmse"] = plotting.plot_rmse
     namespace["plot_cdf"] = plotting.plot_cdf
@@ -1380,6 +1385,7 @@ met_setoutput = make("setoutput")
 metzoom = make("metzoom")
 sub = make("-")
 subset = make("[]")
+met_stdev = make("stdev")
 met_sum = make("sum")
 met_and = make("and")
 met_or = make("or")
